############### FUNCTIONS FOR SCORECARDS ################


## Define metric names

.met_names <- function(metrics, var.units) { # metrics is a object with the names of the metrics to be displayed
  result <- list()
  if ('mean_bias' %in% metrics) {
    result <- append(result, list('mean_bias' = paste0('Mean bias (', var.units,')')))
  }
  if ('enscorr' %in% metrics) {
    result <- append(result, list('enscorr' = 'Correlation'))
  }
  if ('rps' %in% metrics ) {
    result <- append(result, list('rps' = 'RPS'))
  } 
  if ('frps' %in% metrics ) {
    result <- append(result, list('frps' = 'Fair RPS'))
  } 
  if ('rpss' %in% metrics) {
    result <- append(result, list('rpss' = 'RPSS'))
  } 
  if ('rpss_score_aggr' %in% metrics) {
    result <- append(result, list('rpss_score_aggr' = 'RPSS (score aggregated)'))
  } 
  if ('frpss' %in% metrics) {
    result <- append(result, list('frpss' = 'Fair RPSS'))
  }
  if ('crps' %in% metrics) {
    result <- append(result, list('crps' = 'CRPS'))
  } 
  if ('crpss' %in% metrics) {
    result <- append(result, list('crpss' = 'CRPSS'))
  }
  if ('bss10' %in% metrics) {
    result <- append(result, list('bss10' = 'Brier skill score 10%'))
  }
  if ('bss90' %in% metrics) {
    result <- append(result, list('bss90' = 'Brier skill score 90%'))
  }
  if ('enssprerr' %in% metrics ) {
    result <- append(result, list('enssprerr' = 'Spread-to-error ratio'))
  } 
  return(result)
}  



## Define metrics breaks for each input metric

.met_breaks <- function(metrics, breaks_bias) { # metrics is a object with the names of the metrics to be displayed
  result <- list()
  if ('mean_bias' %in% metrics) {
    result <- append(result, list('mean_bias' = breaks_bias))
  }
  if ('enscorr' %in% metrics) {
    result <- append(result, list('enscorr' = c(-1, -0.8, -0.6, -0.4, -0.2, 0, 0.2, 0.4, 0.6, 0.8, 1)))
  }
  if ('rps' %in% metrics ) {
    result <- append(result, list('rps' = c(0, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.8, 1)))
  } 
  if ('frps' %in% metrics ) {
    result <- append(result, list('frps' = c(-0.5, -0.4, -0.3, -0.2, -0.1, 0, 0.1, 0.2, 0.3, 0.4, 0.5)))
  } 
  if ('rpss' %in% metrics) {
    result <- append(result, list('rpss' = c(-0.5, -0.4, -0.3, -0.2, -0.1, 0, 0.1, 0.2, 0.3, 0.4, 0.5)))
  } 
  if ('rpss_score_aggr' %in% metrics) {
    result <- append(result, list('rpss_score_aggr' = c(-0.5, -0.4, -0.3, -0.2, -0.1, 0, 0.1, 0.2, 0.3, 0.4, 0.5)))
  } 
  if ('frpss' %in% metrics) {
    result <- append(result, list('frpss' = c(-0.5, -0.4, -0.3, -0.2, -0.1, 0, 0.1, 0.2, 0.3, 0.4, 0.5)))
  }
  if ('crps' %in% metrics) {
    result <- append(result, list('crps' = c(-0.5, -0.4, -0.3, -0.2, -0.1, 0, 0.1, 0.2, 0.3, 0.4, 0.5)))
  } 
  if ('crpss' %in% metrics) {
    result <- append(result, list('crpss' = c(-0.5, -0.4, -0.3, -0.2, -0.1, 0, 0.1, 0.2, 0.3, 0.4, 0.5)))
  }
  if ('bss10' %in% metrics) {
    result <- append(result, list('bss10' = c(-0.5, -0.4, -0.3, -0.2, -0.1, 0, 0.1, 0.2, 0.3, 0.4, 0.5)))
  }
  if ('bss90' %in% metrics) {
    result <- append(result, list('bss90' = c(-0.5, -0.4, -0.3, -0.2, -0.1, 0, 0.1, 0.2, 0.3, 0.4, 0.5)))
  }
  if ('enssprerr' %in% metrics ) {
    result <- append(result, list('enssprerr' = c(0, 0.6, 0.7, 0.8, 0.9, 1, 1.2, 1.4, 1.6, 1.8, 2)))
  } 
  return(result)
}  
