###############################################################################
################## SCRIPT FOR LOADING ALL SCORECARD FUNCTIONS #################
###############################################################################

##### Script requires module Phantomjs, currently loaded in WS
##### If using Nord3, the module needs to be loaded before running the code
##### To load Phantomjs in Nord3: module load Phantomjs

##### To open R in Nord3: 
#  module load R/4.1.2-foss-2019b
#  module load OpenMPI/4.0.5-GCC-8.3.0-nord3-v2
#  R

## Cleaning
rm(list = ls()); gc()

### Set the working directory containing the scripts
setwd("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/")


##### Load libraries ######
library(ncdf4) ## to load netCDF files
library(formattable) ## to plot horizontal color bars
library(kableExtra) ## to print data in formatted tables
library(stringr) ## for manipulating capitals in the figure title
library(s2dv) ## for function ColorBar() 
library(abind) ## for function abind()
library(data.table) ## for function %like%
library(ClimProjDiags) ## for WeightedMean function
library(yaml) ## to read yaml files



system <- c('ecmwfs5', 'cmccs35')
reference <- 'era5'
var <- 'sfcWind' ## tas, prlr, psl , sfcWind
start.year <- 1993
end.year <- 2016
metrics.load =  c('mean_bias', 'enscorr', 'rpss', 'crpss', 'enssprerr')
metrics.visualize = c('mean_bias', 'enscorr', 'rpss', 'crpss', 'enssprerr')
start.months <- 1:12
forecast.months <- 1:6
cross.validation <- FALSE
metric.aggregation <- 'skill'
skill_from_score <- FALSE

regions <- list('Tropics' = c(lon.min = 0, lon.max = 360, lat.min = -30, lat.max = 30),
               'Extra-tropical NH' = c(lon.min = -0, lon.max = 360, lat.min = 30, lat.max = 90),
               'Extra-tropical SH' = c(lon.min = 0, lon.max = 360, lat.min = -30, lat.max = -90))
region.names <- c('Tropics', 'Extra-tropical NH', 'Extra-tropical SH')


if(cross.validation == TRUE){
  input.path <- '/esarchive/scratch/nmilders/scorecards_data/input_data/cross-validation'
  fileout <- '/esarchive/scratch/nmilders/saved_scorecards/cross-validation'
}
if(cross.validation == FALSE){
  input.path <- '/esarchive/scratch/nmilders/scorecards_data/input_data/not-cross-validation'
  fileout <- '/esarchive/scratch/nmilders/saved_scorecards/not-cross-validation'
}

## Location where the scorecards images are saved
fileout <- '/esarchive/scratch/nmilders/saved_scorecards/testing'


### For Decathlon ###
# regions <- list('España'= c(lon.min = -10, lon.max = 5, lat.min = 35, lat.max = 44),
#                'Galicia-Cantabrico' = c(lon.min = -10, lon.max = -1, lat.min = 42, lat.max = 44),
#                'Cataluña' = c(lon.min = 0, lon.max = 3.5, lat.min = 40, lat.max = 43),
#                'Valencia-Murcia' = c(lon.min = -2 , lon.max = 0.5 , lat.min = 37 , lat.max = 40.5)),
#region.names <- c('ESPAÑA', 'Galicia-Cantabrico', 'Cataluña', 'Valencia-Murcia')
#fileout <- '/esarchive/scratch/nmilders/decathlon'


## Load data files
source("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/modules/Scorecards/SC_1_load_metrics.R")
loaded_metrics <- SC_load_metrics(system = system,
                                  reference = reference,
                                  var = var,
                                  start.year = start.year,
                                  end.year = end.year,
                                  metrics =  metrics.load,
                                  start.months = sprintf("%02d", start.months),
                                  forecast.months = forecast.months,
                                  input.path = input.path)



## Calculate weighted mean of spatial aggregation
source("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/modules/Scorecards/SC_2_spatial_aggregation.R")
aggregated_metrics <- SC_spatial_aggregation(loaded_metrics,
                                             regions = regions,
                                             skill_from_score = skill_from_score,
                                             ncores = 4)

## Create simple scorecard tables 
## (one system only)
## Metrics input must be in the same order as function SC_spatial_aggregation
source("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/modules/Scorecards/SC_3_create_scorecard_simple.R")
scorecard_simple <- SC_create_table_simple(data = aggregated_metrics,
                                           system = system,
                                           reference = reference,
                                           var = var, 
                                           start.year = start.year,
                                           end.year = end.year,
                                           start.months = start.months,
                                           forecast.months = forecast.months,
                                           region.names = region.names,
                                           metrics = metrics.visualize,
                                           cross.validation = cross.validation,
                                           metric.aggregation = metric.aggregation,
                                           fileout = fileout)


## Create multi system/reference scorecard tables 
## (multiple systems with one reference or one system with multiple references)
## Metrics input must be in the same order as function SC_spatial_aggregation
if(length(system) >  1 || length(reference) >  1){
  source("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/modules/Scorecards/SC_4_create_scorecard_multi.R")
  scorecard_multi <- SC_create_table_multi(data = aggregated_metrics,
                                             system = system,
                                             reference = reference,
                                             var = var, 
                                             start.year = start.year,
                                             end.year = end.year,
                                             start.months = start.months,
                                             forecast.months = forecast.months,
                                             region.names = region.names,
                                             metrics = metrics.visualize,
                                             cross.validation = cross.validation,
                                             metric.aggregation = metric.aggregation,
                                             fileout = fileout)
}


